@@ -28,8 +28,8 @@
 class Library {
 	// CLASS FUNCTIONS
 	// Library
-	// selLibraryItems
 	// getPages
+	// selLibraryItems
 	// getPageName
 	// getPageID
 	// getPageDefault
@@ -114,7 +114,7 @@ class Library {
 		;
 		
 		if (isset($this->rsp_item_type_id)) {
-			$query .= ", pr.profile_create_datetime, pr.profile_nic, pr.profile_hometown, rsp.rsp_sticky ";
+			$query .= ", pr.profile_create_datetime, pr.profile_nic, pr.profile_hometown, rsp.rsp_sticky, rsp.rsp_featured ";
 		}
 			
 		$query .= "FROM " . $this->db->prefix . "_library l ";
@@ -124,8 +124,8 @@ class Library {
 		}
 		
 		if (isset($this->rsp_item_type_id)) {
-			$query .= ", " . $this->db->prefix . "_rsp rsp 
-			LEFT JOIN " . $this->db->prefix . "_user_profile pr ON l.user_id=pr.user_id AND pr.profile_default=1 ";
+			$query .= " LEFT JOIN " . $this->db->prefix . "_user_profile pr ON l.user_id=pr.user_id AND pr.profile_default=1 ";
+			$query .= ", " . $this->db->prefix . "_rsp rsp ";
 		}
 		
 		$query .= "WHERE ";
@@ -149,6 +149,10 @@ class Library {
 			if (isset($this->rsp_status_id)) {
 				$query .= "rsp.status_id=" . $this->rsp_status_id . " AND ";
 			}
+			
+			if (isset($this->rsp_featured)) {
+				$query .= "rsp.rsp_featured=" . $this->rsp_featured . " AND ";
+			}
 		}
 		
 		if (isset($search)) {
@@ -194,7 +198,7 @@ class Library {
 		$query .="1=1 ";
 		
 		if (isset($this->order_by)) {
-		    $query .= "order by l." . $this->order_by;
+		    $query .= "order by " . $this->order_by;
 		}
 		else {
 			$query .= "order by l.library_page_name";
@@ -324,7 +328,7 @@ class Library {
 		$query = "
 			SELECT l.library_id, l.library_page_name, l.library_title, l.library_synopsis,
 			l.file_id, l.library_allow_comments, l.library_create_datetime,
-			l.library_body, l.user_id, l.group_id  
+			l.library_body, l.user_id, l.library_default, l.group_id  
 			FROM " . $this->db->prefix . "_library l 
 			WHERE 
 			l.library_default is not null AND "
@@ -382,7 +386,7 @@ class Library {
 				l.library_page_name=" . $this->db->qstr($pagename, get_magic_quotes_gpc()) . " AND "
 			;
 			
-			if (isset($this->user_id)) { // group list
+			if (isset($this->user_id)) {
 				$query .= "l.user_id=" . $this->user_id . " AND ";
 			}
 			
@@ -542,10 +546,22 @@ class Library {
 			    //we clear out all old default pages
 				$query = "
 					SELECT * FROM " . $this->db->prefix . "_library
-					WHERE 
-					user_id=" . $this->user_id
+					WHERE "
 				;
 				
+				if (isset($this->user_id)) {
+					$query .= "user_id=" . $this->user_id . " AND ";
+				}
+				
+				if (!empty($data['group_id'])) {
+					$query .= "group_id=" . $data['group_id'] . " AND ";
+				}
+				else {
+					$query .= "group_id is NULL AND ";
+				}
+				
+				$query .="1=1";
+				
 				$result = $this->db->Execute($query);
 				
 				$rec = array();
@@ -629,7 +645,5 @@ class Library {
 		}
 
 	}//EO getLibraryItemCount
-
-
 }
 ?>
