@@ -1,9 +1,9 @@
 <?php
 
 // -----------------------------------------------------------------------
-// This file is part of aroundme
+// This file is part of AROUNDMe
 //
-// Copyright (C) 2003, 2005 Barnraiser
+// Copyright (C) 2003 - 2006 Barnraiser
 // http://www.barnraiser.org/
 // info@barnraiser.org
 //
@@ -19,28 +19,27 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with program; see the file COPYING. If not, write to the Free
-// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 // -----------------------------------------------------------------------
 
 ?>
 
+
 <script language="JavaScript" src="js/imageHandling.js" type="text/javascript"></script>
 
 <form action="blg_edit.php" method="post" name="frm" id="id_frm">
-<input type="hidden" name="group_id" value="<?php if(isset($group['group_id'])) { echo $group['group_id'];} elseif (isset($blog['group_id'])) { echo $blog['group_id'];}?>" />
 <input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />
+<input type="hidden" name="group_id" value="<?php if(isset($group['group_id'])) { echo $group['group_id'];} elseif (isset($blog['group_id'])) { echo $blog['group_id'];}?>" />
 
 
-<table width="100%" border="0" cellspacing="0" cellpadding="0">
-	<tr>
-		<td width="760" valign="top">
-			<div class="box_top">
-				<?php echo $lang['section_blog'];?><br />
-			</div>
-
-			<div class="box_mid" style="padding: 9px;">
-
+<div class="box">
+	<div class="box_top">
+		<?php echo $lang['hdr_blog'];?><br />
+	</div>
+		
+	<div class="box_mid">
+		<div class="content">
 			<?php
 			if (isset($display) && $display == "allow_edit") {
 			?>
@@ -50,7 +49,7 @@
 						<b>
 						<?php
 						if (isset($group)) {
-							echo $lang['hdr_group_blog'];
+							echo $lang['hdr_group_blog'] . ": " . $group['group_title'];
 						}
 						else {
 							echo $lang['hdr_blog'];
@@ -78,7 +77,7 @@
 								<td valign="top" width="310">
 									<p>
 									<label for="id_blog_title"><?php echo $lang['form_label_title'];?></label>
-									<input id="id_blog_title" type="text" name="blog_title" size="35" value="<?php if (isset($blog['blog_title'])) { echo $blog['blog_title'];}?>" /><br />
+									<input id="id_blog_title" class="input" type="text" name="blog_title" size="35" value="<?php if (isset($blog['blog_title'])) { echo $blog['blog_title'];}?>" /><br />
 									</p>
 
 									<p>
@@ -90,22 +89,6 @@
 									<img src="<?php echo $templatePath;?>img/pixel.png" width="10" height="1" alt="" /><br />
 								</td>
 								<td valign="top">
-									<p>
-									<label for="id_genre"><?php echo $lang['form_label_genre'];?></label>
-									<select id="id_genre" name="genre_id">
-									<?php
-									foreach($lang['arr_genre'] as $key => $i):
-									$selected = "";
-
-									if (isset($blog['genre_id']) && $blog['genre_id'] == $key) {
-									    $selected = " selected=\"selected\"";
-									}
-									?>
-									<option value="<?php echo $key;?>"<?php echo $selected;?>><?php echo $i;?></option>
-									<?php endforeach; ?>
-									</select>
-									</p>
-
 									<?php
 									if (count($me['language_ids']) > 1) {
 									?>
@@ -113,7 +96,11 @@
 									<label for="id_languages"><?php echo $lang['form_label_language'];?></label>
 									<select name="language_id">
 									<?php foreach($me['language_ids'] as $key => $i): ?>
+										<?php
+										if (isset($lang['arr_lang_name'][$i])) {
+										?>
 										<option value="<?php echo $i;?>" <?php if($me['language_id'] == $i) echo "selected=\"selected\"";?>><?php echo $lang['arr_lang_name'][$i];?></option>
+										<?php }?>
 									<?php endforeach; ?>
 									</select>
 									</p>
@@ -133,59 +120,104 @@
 
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
 
-						<table border="0" cellspacing="0" cellpadding="2" width="10%">
+						<table border="0" cellspacing="0" cellpadding="2">
 							<tr>
 								<td valign="top">
-									<label for="id_blog_body"><?php echo $lang['form_body'];?></label>
-									<div id="gui_wiki" align="right" valign="bottom">
-										<script language="JavaScript" type="text/javascript" src="js/gui_wiki.js"></script>
-									</div>
+									<label for="id_blog_body"><?php echo $lang['form_body'];?></label><br />
+								</td>
+								<td valign="middle" id="gui_wiki" align="right" nowrap="nowrap">
+									<script language="JavaScript" type="text/javascript" src="js/gui_wiki.js"></script>&nbsp;<br />
+								</td>
+								<td width="1" valign="top">
+									<select class="gui_select" onChange="javascript:insertTags('[', ' link name here]', this.value);">
+										<option value="0"><?php echo $lang['txt_wikipagenames'];?></option>
+										<?php
+										if (isset($wikipages)) {
+										foreach($wikipages as $key => $i):
+										?>
+										<option><?php echo $i;?></option>
+										<?php
+										endforeach;
+										}
+										?>
+									</select>
+									<br />
+								</td>
+								<td width="1">
+									<script language="JavaScript" type="text/javascript">
+									function fileSuffixCheck (filename) {
+										
+										var suffix = filename.substring(filename.length-3);
+										
+										if (suffix=='jpg' || suffix=='png' || suffix=='gif') {
+											var wikiTag = "Image ";
+											var thumb = "";
+										}
+										else {
+											var wikiTag = "File ";
+											var thumb = " thumb=1";
+										}
+										
+										insertTags('[['+wikiTag , filename+thumb+']]', '')
+									}
+									</script>
+									
+									<select class="gui_select" onChange="javascript:fileSuffixCheck(this.value);">
+										<option value="0"><?php echo $lang['txt_filenames'];?></option>
+										<?php
+										if (isset($filenames)) {
+										foreach($filenames as $key => $i):
+										?>
+										<option><?php echo $i['file_name'] . "." . $i['file_suffix'];?></option>
+										<?php
+										endforeach;
+										}
+										?>
+									</select>
+									<br />
 								</td>
 							</tr>
 							<tr>
-								<td>
-									<textarea id="id_blog_body" name="blog_body" cols="78" rows="10" onchange="textChanged = true;" tabindex="1"><?php if (isset($blog['blog_body'])) { echo $blog['blog_body'];}?></textarea><br />
+								<td align="right" colspan="4">
+									<textarea id="id_blog_body" name="blog_body" cols="75" rows="10" onchange="textChanged = true;" tabindex="1"><?php if (isset($blog['blog_body'])) { echo $blog['blog_body'];}?></textarea><br />
 									<script language="JavaScript" type="text/javascript">
 										var txtarea = document.frm.blog_body;
 									</script>
 								</td>
 							</tr>
 							<tr>
-								<td align="right">
-									<input type="submit" name="preview" value="<?php echo $lang['form_submit_preview'];?>" class="button_light" />
+								<td align="right" colspan="4">
+									<input type="submit" class="input_submit" name="preview" value="<?php echo $lang['sub_preview'];?>" />
 									<?php
 									if (isset($allow_spellcheck)) {
 									?>
 									&nbsp;&nbsp;
-									<input type="button" value="<?php echo $lang['txt_check_spelling'];?>" onClick="openSpellChecker();" class="button_light" />
+									<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" class="button_light" />
 									<?php }?>
 									<br />
 								</td>
 							</tr>
-
-							<?php
-							if (!empty($blog['blog_body_preview'])) {
-							?>
-
-							<tr>
-								<td>
-									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
-								</td>
-							</tr>
-							<tr>
-								<td>
-									<?php echo $lang['form_label_preview'];?><br />
-								</td>
-							</tr>
-							<tr>
-								<td class="picture_light">
-									<?php echo $blog['blog_body_preview'];?><br />
-								</td>
-							</tr>
-							<?php }?>
 						</table>
+						
+						<?php
+						if (!empty($blog['blog_body_preview'])) {
+						?>
+						
+						<p>
+							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
+						</p>
+						
+						<p>
+							<?php echo $lang['form_label_preview'];?><br />
+						</p>
+							
+						<p>
+							<?php echo $blog['blog_body_preview'];?><br />
+						</p>
+						<?php }?>
+						
 						</fieldset>
-
+						
 					</td>
 					<td>
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="10" height="1" alt="" /><br />
@@ -246,35 +278,60 @@
 						//find out what value rsp has
 						if (isset($blog['rsp'])) {
 							foreach($blog['rsp'] as $key => $rsp):
-								if ($rsp['level_id'] == $rspconfig['rsp_level']['degree']) {
-									$rsp_degree_set = 1;
-									$rsp_degree = $rsp['degree_id'];
-								}
-								elseif ($rsp['level_id'] == $rspconfig['rsp_level']['node']) {
+								if ($rsp['level_id'] == $rspconfig['rsp_level']['node']) {
 									$rsp_node = 1;
+									$rsp_degree = $rsp['degree_id'];
+									$rsp_node_featured = $rsp['rsp_featured'];
 								}
 								elseif ($rsp['level_id'] == $rspconfig['rsp_level']['public']) {
 									$rsp_public = 1;
+									$rsp_public_featured = $rsp['rsp_featured'];
 								}
 								elseif ($rsp['level_id'] == $rspconfig['rsp_level']['group']['home']) {
 									$rsp_group_home = 1;
 								}
 							endforeach;
 						}
-
-
-						if (isset($group)) {
 						?>
-						<table border="0" cellspacing="0" cellpadding="4" width="100%">
+						
+						<script type="text/javascript">
+						function setNodeAll(id) {
+							if (id.checked) {
+								document.getElementById('id_node_id').checked=true;
+							}
+						}
+						function setPub(id) {
+							if (id.checked) {
+								document.getElementById('id_level_id_public').checked=true;
+							}
+						}
+						function setPublishingOff() {
+							document.getElementById('id_node_featured').checked=false;
+
+						}
+						function setPubPublishingOff() {
+							document.getElementById('id_public_featured').checked=false;
+
+						}
+						</script>
+
+						<table border="0" cellspacing="0" cellpadding="2" width="100%">
 							<?php
-							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_public'])) { //resource_id, Priv_id
+							if (isset($group)) {
+							if ($this->group_acs->checkPermission($resource_ids['group']['rsp'], $privilege_ids['allow_rsp_public'])) { //resource_id, Priv_id
+								if ($rspconfig['public']['auto_publish'] == 1) {
+									$txt_rsp_public = $lang['txt_publish_auto_public_help'];
+								}
+								else {
+									$txt_rsp_public = $lang['txt_publish_public_help'];
+								}
 							?>
 							<tr>
 								<td valign="top">
 									<input id="id_allow_rsp_public" type="checkbox" name="rsp_public" class="checkbox" value="1" <?php if (isset($rsp_public) && $rsp_public == 1) { echo "checked=\"checked\"";}?> />
 								</td>
 								<td valign="top">
-									<label style="width:100%" for="id_allow_rsp_public"><?php echo $lang['txt_publish_public_help'];?></label><br />
+									<label style="width:100%" for="id_allow_rsp_public"><?php echo $txt_rsp_public;?></label><br />
 								</td>
 							</tr>
 							<tr>
@@ -284,12 +341,12 @@
 							<tr>
 							<?php 
 							}
-							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
+							if ($this->group_acs->checkPermission($resource_ids['group']['rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
 								if ($rspconfig['node']['auto_publish'] == 1) {
-									$txt_rsp_node = $lang['form_rsp_node_auto'];
+									$txt_rsp_node = $lang['txt_publish_auto_node_help'];
 								}
 								else {
-									$txt_rsp_node = $lang['form_rsp_node'];
+									$txt_rsp_node = $lang['txt_publish_node_help'];
 								}
 							?>
 							<tr>
@@ -308,12 +365,12 @@
 							<?php
 							}
 
-							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_group_home'])) { //resource_id, Priv_id
+							if ($this->group_acs->checkPermission($resource_ids['group']['rsp'], $privilege_ids['allow_rsp_group_home'])) { //resource_id, Priv_id
 								if ($group['group_rsp_auto_publish'] == 1) {
-									$txt_rsp_group = $lang['form_rsp_group_auto'];
+									$txt_rsp_group = $lang['txt_publish_auto_group_help'];
 								}
 								else {
-									$txt_rsp_group = $lang['form_rsp_group'];
+									$txt_rsp_group = $lang['txt_publish_group_help'];
 								}
 							?>
 							<tr>
@@ -326,139 +383,196 @@
 								</td>
 							</tr>
 							<?php } ?>
-							<tr>
-								<td colspan="2">
-									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
-								</td>
-							<tr>
-							<tr>
-								<td valign="top">
-									<input id="id_allow_comments" type="checkbox" name="blog_allow_comments" class="checkbox" value="1" <?php if (isset($blog['blog_allow_comments']) && $blog['blog_allow_comments'] == 1) { echo "checked=\"checked\"";}?> /><br />
-								</td>
-								<td valign="top">
-									<label style="width:100%" for="id_allow_comments"><?php echo $lang['form_label_comments'];?></label><br />
-								</td>
-							</tr>
-						</table>
-						<?php
-						}
-						else {
-						?>
-
-						<script type="text/javascript">
-						function setDegreeEveryone(id) {
-							if (id.checked) {
-								document.getElementById('id_degree_id').checked=true;
+							<?php
 							}
-						}
-						function setPublishingOff() {
-							document.getElementById('id_level_id_node').checked=false;
-							document.getElementById('id_level_id_public').checked=false;
-
-						}
-						</script>
-
-						<table border="0" cellspacing="0" cellpadding="2" width="100%">
+							else {
+							?>
 							<tr>
-								<td width="1">
-									<input type="radio" name="rsp_degree" class="checkbox" value="" checked="checked" /><br />
+								<td width="1" valign="middle">
+									<input type="radio" class="checkbox" name="rsp_node" value="" checked="checked" onClick="javascript:setPublishingOff();" /><br />
 								</td>
-								<td>
+								<td valign="middle">
 									<?php echo $lang['form_just_me'];?><br />
 								</td>
 							</tr>
-							<?php
-							$selected="";
-							foreach($lang['sn']['degree'] as $key => $i):
-
-							if (isset($rsp_degree) && $key == $rsp_degree) {
-								$selected=" checked=\"checked\"";
-							}
-							?>
-							<tr>
-								<td width="1">
-									<input type="radio" name="rsp_degree" class="checkbox" value="<?php echo $key;?>"<?php echo $selected;?> onClick="javascript:setPublishingOff();" /><br />
-								</td>
-								<td>
-									<?php echo $i;?><br />
-								</td>
-							</tr>
-							<?php
-							$selected="";
-							endforeach;
-							if (isset($rsp_degree_set) && empty($rsp_degree)) {
-								$selected=" checked=\"checked\"";
-							}
-							?>
-							<tr>
-								<td>
-									<input id="id_degree_id" type="radio" class="checkbox" name="rsp_degree" value="all"<?php echo $selected;?> /><br />
-								</td>
-								<td>
-									<?php echo $lang['txt_publish_level'];?><br />
-								</td>
-							</tr>
-							<?php
-
-							if ($this->user_acs->checkPermission($resource_ids['rsp'], $privilege_ids['allow_rsp_node'])) { //resourece_id, Priv_id
-							$selected="";
-							if (isset($rsp_node) && $rsp_node == 1) {
-								$selected=" checked=\"checked\"";
-							}
-							?>
-							<tr>
-								<td valign="top">
-									<input type="checkbox" id="id_level_id_node" name="rsp_node" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setDegreeEveryone(this);" /><br />
-								</td>
-								<td>
-									<?php echo $lang['txt_publish_node_help'];?><br />
-								</td>
-							</tr>
-							<?php
-							}
-
-							if ($this->user_acs->checkPermission($resource_ids['rsp'], $privilege_ids['allow_rsp_public'])) { //resourece_id, Priv_id
-							$selected="";
-							if (isset($rsp_public) && $rsp_public == 1) {
-								$selected=" checked=\"checked\"";
-							}
-							?>
-							<tr>
-								<td valign="top">
-									<input type="checkbox" id="id_level_id_public" name="rsp_public" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setDegreeEveryone(this);" /><br />
-								</td>
-								<td>
-									<?php echo $lang['txt_publish_public_help'];?><br />
-								</td>
-							</tr>
-							<?php }?>
 							<tr>
 								<td colspan="2">
 									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
 								</td>
 							<tr>
+							<?php
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_network'])) { //resource_id, Priv_id
+							$selected="";
+							if (isset($rsp_node) && isset($rsp_degree)) {
+								$selected=" checked=\"checked\"";
+							}
+							?>
 							<tr>
-								<td valign="top">
-									<input id="id_allow_comments" type="checkbox" name="blog_allow_comments" class="checkbox" value="1" <?php if (isset($blog['blog_allow_comments']) && $blog['blog_allow_comments'] == 1) { echo "checked=\"checked\"";}?> /><br />
+								<td width="1" valign="middle">
+									<input type="radio" name="rsp_node" class="checkbox" value="1"<?php echo $selected;?> onClick="javascript:setPublishingOff();" /><br />
 								</td>
-								<td valign="top">
-									<label style="width:100%" for="id_allow_comments"><?php echo $lang['form_label_comments'];?></label><br />
+								<td valign="middle">
+									<?php echo $lang['txt_degree_nw'];?><br />
 								</td>
 							</tr>
+							<tr>
+								<td colspan="2">
+									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
+								</td>
+							<tr>
+							<?php }?>
+							
+							<?php
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
+							$selected="";
+							if (isset($rsp_node) && empty($rsp_degree)) {
+								$selected=" checked=\"checked\"";
+							}
+							?>
+							<tr>
+								<td valign="middle">
+									<input id="id_node_id" type="radio" class="checkbox" name="rsp_node" value="all"<?php echo $selected;?> /><br />
+								</td>
+								<td valign="middle">
+									<?php echo $lang['txt_publish_all'];?><br />
+								</td>
+							</tr>
+							<tr>
+								<td colspan="2">
+									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
+								</td>
+							<tr>
+							<?php }?>
+							
+							<?php
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_public'])) { //resource_id, Priv_id
+							$selected="";
+							if (isset($rsp_public)) {
+								$selected=" checked=\"checked\"";
+							}
+							?>
+							<tr>
+								<td valign="top">
+									<input type="checkbox" id="id_level_id_public" name="rsp_public" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setPubPublishingOff();" /><br />
+								</td>
+								<td>
+									<?php echo $lang['form_public'];?><br />
+								</td>
+							</tr>
+							<tr>
+								<td colspan="2">
+									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
+								</td>
+							<tr>
+							<?php }?>
+							
+							
+							<?php
+							// write the featured item checkboxes
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_node_featured'])) { //resource_id, Priv_id
+							$selected="";
+							if (!empty($rsp_node_featured)) {
+								$selected=" checked=\"checked\"";
+							}
+							
+							if ($rspconfig['node']['auto_publish'] == 1) {
+								$txt_rsp_node = $lang['txt_publish_auto_node_help'];
+							}
+							else {
+								$txt_rsp_node = $lang['txt_publish_node_help'];
+							}
+							?>
+							<tr>
+								<td valign="top">
+									<input type="checkbox" id="id_node_featured" name="rsp_node_featured" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setNodeAll(this);" /><br />
+								</td>
+								<td>
+									<?php echo $txt_rsp_node;?><br />
+								</td>
+							</tr>
+							<tr>
+								<td colspan="2">
+									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
+								</td>
+							<tr>
+							<?php
+							}
+
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_public_featured'])) { //resource_id, Priv_id
+							$selected="";
+							if (!empty($rsp_public_featured)) {
+								$selected=" checked=\"checked\"";
+							}
+							
+							if ($rspconfig['public']['auto_publish'] == 1) {
+								$txt_rsp_public = $lang['txt_publish_auto_public_help'];
+							}
+							else {
+								$txt_rsp_public = $lang['txt_publish_public_help'];
+							}
+							?>
+							<tr>
+								<td valign="top">
+									<input type="checkbox" id="id_public_featured" name="rsp_public_featured" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setPub(this);" /><br />
+								</td>
+								<td>
+									<?php echo $txt_rsp_public;?><br />
+								</td>
+							</tr>
+							<?php }}?>
 						</table>
-						<?php }?>
 						</fieldset>
 
 						<script type="text/javascript">
 						//check php did not set either of the publishing buttons
-						if (document.getElementById('id_level_id_public').checked) {
-							document.getElementById('id_degree_id').checked=true;
+						if (document.getElementById('id_public_featured').checked) {
+							document.getElementById('id_node_id').checked=true;
 						}
-						if (document.getElementById('id_level_id_node').checked) {
-							document.getElementById('id_degree_id').checked=true;
+						if (document.getElementById('id_node_featured').checked) {
+							document.getElementById('id_node_id').checked=true;
 						}
 						</script>
 
+						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
+						
+						<fieldset>
+						<legend><?php echo $lang['txt_header_7'];?></legend>
+						
+						<table border="0" cellspacing="0" cellpadding="2" width="100%">
+							<tr>
+								<td valign="top">
+									<?php
+									$selected = "";
+									// if no blog we are adding and we check the box
+									if (isset($blog['blog_allow_comments']) && $blog['blog_allow_comments'] == 1) {
+										$selected = "checked=\"checked\"";
+									}
+									elseif (!isset($blog)) {
+										$selected = "checked=\"checked\"";
+									}
+									?>
+									<input id="id_allow_comments" type="checkbox" name="blog_allow_comments" class="checkbox" value="1" <?php echo $selected;?> /><br />
+								</td>
+								<td valign="top">
+									<label style="width:100%" for="id_allow_comments"><?php echo $lang['form_label_comments'];?></label><br />
+								</td>
+							</tr>
+							<tr>
+								<td colspan="2">
+									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
+								</td>
+							<tr>
+							<tr>
+								<td valign="top">
+									<input id="id_track" type="checkbox" name="ins_mark" class="checkbox" value="1" <?php if (!empty($blog['bookmark']['bookmark_notify'])) { echo "checked=\"checked\"";}?> /><br />
+								</td>
+								<td valign="top">
+									<label style="width:100%" for="id_track"><?php echo $lang['form_label_track'];?></label><br />
+								</td>
+							</tr>
+						</table>
+						</fieldset>
+
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
 
 						<fieldset>
@@ -469,8 +583,8 @@
 
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
 
-						<input type="submit" name="save" class="button_urgent" value="<?php echo $lang['form_submit_save'];?>" />&nbsp;
-						<input type="submit" name="save_go" class="button_urgent" value="<?php echo $lang['form_submit_save_go'];?>" /><br />
+						<input type="submit" class="input_submit" name="save" value="<?php echo $lang['sub_save'];?>" />&nbsp;
+						<input type="submit" class="input_submit" name="save_go" value="<?php echo $lang['sub_save_go'];?>" /><br />
 
 						</fieldset>
 					</td>
@@ -485,24 +599,12 @@
 			<?php echo $lang['err_blog_item_edit'];?><br />
 
 			<?php }?>
-			</div>
+		</div>
+	</div>
+</div>
 
-			<div id="box_bottom">
-				<table cellpadding="0" cellspacing="0" border="0" width="100%">
-					<tr>
-						<td align="left">
-							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
-						</td>
-						<td align="left">
-							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
-						</td>
-						<td align="right">
-							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
-						</td>
-					</tr>
-				</table>
-			</div>
-		</td>
-	</tr>
-</table>
+<div class="box_bottom">
+	<span class="box_bottom_right"></span>
+	<span class="box_bottom_left"></span>
+</div>
 </form>
