@@ -73,7 +73,7 @@
 					<?php }?>
 					
 					<?php
-					if (!isset($blog['bookmark']['watch']) && $batch_enabled == true) {
+					if (!isset($blog['bookmark']['watch']) && isset($batch_enabled) && $batch_enabled == true) {
 					?>
 					,&nbsp;
 					<a href="blg_view.php?blog_id=<?php echo $blog['blog_id'];?>&amp;bookmark=ins_mark&amp;notify=1"><?php echo $lang['href_watch_this_notify'];?></a>
@@ -157,13 +157,22 @@
 						<?php
 						if (isset($blog['rsp'])) {
 							foreach($blog['rsp'] as $key => $i):
+								if (!empty($i['degree_id']) && $i['level_id'] == $rspconfig['rsp_level']['node']) {
+									echo $lang['rsp']['rsp_level_degree'][$i['degree_id']];
+								}
+								else {
+									echo trim($lang['rsp']['rsp_level'][$i['level_id']]);
+								}
+								echo " (" .$lang['rsp']['status'][$i['status_id']];
 								
-								echo trim($lang['rsp']['rsp_level'][$i['level_id']] . " " . $i['degree_id']);
-								echo " (" .$lang['rsp']['status'][$i['status_id']] . ")";
+								if (!empty($i['rsp_featured'])) {
+									echo " &amp; " .  $lang['txt_featured'];
+								}
+								
+								echo ")";
 								if ($key+1 < count($blog['rsp'])) {
 									echo ", ";
 								}
-								
 							endforeach;
 						}
 					?>
@@ -900,14 +909,8 @@
 						foreach ($item_tags as $key => $i):
 							$tags .= "<a href='search.php?tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>";
 							
-							//mark my tags
-							if (isset($my_tags)) {
-								foreach ($my_tags as $key => $mt):
-									if ($i['tag_body'] == $mt['tag_body']) {
-										$tags .= "*";
-										break;
-									}
-								endforeach;
+							if (isset($me['user_id']) && $i['user_id'] == $me['user_id']) {
+								$tags .= "*";
 							}
 							
 							if (count($item_tags) > $key+1) {
